@@ -3,9 +3,10 @@
  *
  *		Copyright 1996-2001	Cistron Internet Services B.V.
  *		Copyright 2002-2003	Cistron IP B.V.
+ *		Copyright 2006		Miquel van Smoorenburg
  */
 char acct_rcsid[] =
-"$Id: acct.c,v 1.26 2003/07/03 08:09:04 miquels Exp $";
+"$Id: acct.c,v 1.28 2006/02/08 17:05:53 miquels Exp $";
 
 #include	<sys/types.h>
 #include	<sys/socket.h>
@@ -229,7 +230,7 @@ int radzap(UINT4 nasaddr, UINT4 port, char *user, time_t t, int dowtmp)
 			 *	Match. Zap it.
 			 */
 			if (lseek(fd, -(off_t)sizeof(u), SEEK_CUR) < 0) {
-				log(L_ERR, "Accounting: radzap: negative lseek!\n");
+				log_msg(L_ERR, "Accounting: radzap: negative lseek!\n");
 				lseek(fd, (off_t)0, SEEK_SET);
 			}
 			u.type = P_IDLE;
@@ -281,7 +282,7 @@ int rad_accounting_radxtmp(AUTH_REQ *authreq, int dowtmp, int doutmp)
 	 *	Which type is this.
 	 */
 	if ((vp = pairfind(authreq->request, PW_ACCT_STATUS_TYPE)) == NULL) {
-		log(L_ERR, "Accounting: no Accounting-Status-Type record.");
+		log_msg(L_ERR, "Accounting: no Accounting-Status-Type record.");
 		return -1;
 	}
 	status = vp->lvalue;
@@ -317,13 +318,13 @@ int rad_accounting_radxtmp(AUTH_REQ *authreq, int dowtmp, int doutmp)
 			check2 = 1;
 		if (check1 == 0 || check2 == 0) {
 #if 0 /* Cisco sometimes sends START records without username. */
-			log(L_ERR, "Accounting: no username in record");
+			log_msg(L_ERR, "Accounting: no username in record");
 			return -1;
 #else
 			break;
 #endif
 		}
-		log(L_INFO, "Accounting: converting reboot records.");
+		log_msg(L_INFO, "Accounting: converting reboot records.");
 		if (status == PW_STATUS_STOP)
 			status = PW_STATUS_ACCOUNTING_OFF;
 		if (status == PW_STATUS_START)
@@ -440,14 +441,14 @@ int rad_accounting_radxtmp(AUTH_REQ *authreq, int dowtmp, int doutmp)
 	 *	See if this was a portmaster reboot.
 	 */
 	if (status == PW_STATUS_ACCOUNTING_ON && nas_address) {
-		log(L_INFO, "NAS %s restarted (Accounting-On packet seen)",
+		log_msg(L_INFO, "NAS %s restarted (Accounting-On packet seen)",
 			nas_name(nas_address));
 		if (doutmp)
 			radzap(nas_address, -1, NULL, ut.time, dowtmp);
 		return 0;
 	}
 	if (status == PW_STATUS_ACCOUNTING_OFF && nas_address) {
-		log(L_INFO, "NAS %s rebooted (Accounting-Off packet seen)",
+		log_msg(L_INFO, "NAS %s rebooted (Accounting-Off packet seen)",
 			nas_name(nas_address));
 		if (doutmp)
 			radzap(nas_address, -1, NULL, ut.time, dowtmp);
@@ -460,7 +461,7 @@ int rad_accounting_radxtmp(AUTH_REQ *authreq, int dowtmp, int doutmp)
 	if (status != PW_STATUS_START &&
 	    status != PW_STATUS_STOP &&
 	    status != PW_STATUS_ALIVE) {
-		log(L_ERR, "NAS %s port %u unknown packet type %u)",
+		log_msg(L_ERR, "NAS %s port %u unknown packet type %u)",
 			nas_name(nas_address), ut.nas_port, status);
 		return 0;
 	}
@@ -519,7 +520,7 @@ int rad_accounting_radxtmp(AUTH_REQ *authreq, int dowtmp, int doutmp)
 				 *	send _only_ logout records).
 				 */
 				if (u.type == P_LOGIN)
-					log(L_ERR,
+					log_msg(L_ERR,
 		"Accounting: logout: entry for NAS %s port %u has wrong ID",
 					nas_name(nas_address), u.nas_port);
 				r = -1;
@@ -531,14 +532,14 @@ int rad_accounting_radxtmp(AUTH_REQ *authreq, int dowtmp, int doutmp)
 			     sizeof(u.session_id)) == 0  &&
 			    u.time >= ut.time) {
 				if (u.type == P_LOGIN) {
-					log(L_INFO,
+					log_msg(L_INFO,
 		"Accounting: login: entry for NAS %s port %u duplicate",
 					nas_name(nas_address), u.nas_port);
 					r = -1;
 					dowtmp = 0;
 					break;
 				}
-				log(L_ERR,
+				log_msg(L_ERR,
 		"Accounting: login: entry for NAS %s port %u wrong order",
 				nas_name(nas_address), u.nas_port);
 				r = -1;
@@ -563,7 +564,7 @@ int rad_accounting_radxtmp(AUTH_REQ *authreq, int dowtmp, int doutmp)
 			}
 
 			if (lseek(fd, -(off_t)sizeof(u), SEEK_CUR) < 0) {
-				log(L_ERR, "Accounting: negative lseek!\n");
+				log_msg(L_ERR, "Accounting: negative lseek!\n");
 				lseek(fd, (off_t)0, SEEK_SET);
 				off = 0;
 			} else
@@ -593,7 +594,7 @@ int rad_accounting_radxtmp(AUTH_REQ *authreq, int dowtmp, int doutmp)
 				u.delay = ut.delay;
 				write(fd, &u, sizeof(u));
 			} else if (r == 0) {
-				log(L_ERR,
+				log_msg(L_ERR,
 		"Accounting: logout: login entry for NAS %s port %u not found",
 				nas_name(nas_address), ut.nas_port);
 				r = -1;
@@ -601,7 +602,7 @@ int rad_accounting_radxtmp(AUTH_REQ *authreq, int dowtmp, int doutmp)
 		}
 		close(fd);
 	} else if (fd < 0) {
-		log(L_ERR, "Accounting: %s: %s", radutmp_path, strerror(errno));
+		log_msg(L_ERR, "Accounting: %s: %s", radutmp_path, strerror(errno));
 		ret = -1;
 	}
 
@@ -747,7 +748,7 @@ int rad_accounting_detail(AUTH_REQ *authreq, int authtype, char *f)
 	 */
 	do {
 		if ((outfd = fopen(detail, "a")) == NULL) {
-			log(L_ERR, "Acct: Couldn't open file %s", detail);
+			log_msg(L_ERR, "Acct: Couldn't open file %s", detail);
 			ret = -1;
 			break;
 		}
@@ -898,7 +899,7 @@ static int rad_check_ts(struct radutmp *ut)
 	 *	Find NAS type.
 	 */
 	if ((nas = nas_find(ntohl(ut->nas_address))) == NULL) {
-		log(L_ERR, "Accounting: unknown NAS");
+		log_msg(L_ERR, "Accounting: unknown NAS");
 		return -1;
 	}
 
@@ -911,7 +912,7 @@ static int rad_check_ts(struct radutmp *ut)
 	 */
 	handler = signal(SIGCHLD, SIG_DFL);
 	if ((pid = fork()) < 0) {
-		log(L_ERR, "Accounting: fork: %s", strerror(errno));
+		log_msg(L_ERR, "Accounting: fork: %s", strerror(errno));
 		signal(SIGCHLD, handler);
 		return -1;
 	}
@@ -933,11 +934,11 @@ static int rad_check_ts(struct radutmp *ut)
 			kill(pid, SIGTERM);
 			sleep(1);
 			kill(pid, SIGKILL);
-			log(L_ERR, "Check-TS: timeout waiting for checkrad");
+			log_msg(L_ERR, "Check-TS: timeout waiting for checkrad");
 			return 2;
 		}
 		if (e < 0) {
-			log(L_ERR, "Check-TS: unknown error in waitpid()");
+			log_msg(L_ERR, "Check-TS: unknown error in waitpid()");
 			return 2;
 		}
 		return WEXITSTATUS(st);
@@ -964,7 +965,7 @@ static int rad_check_ts(struct radutmp *ut)
 		execl(CHECKRAD1, "checkrad", nas->nastype, address, port,
 			ut->login, session_id, NULL);
 	}
-	log(L_ERR, "Check-TS: exec %s: %s", s, strerror(errno));
+	log_msg(L_ERR, "Check-TS: exec %s: %s", s, strerror(errno));
 
 	/*
 	 *	Exit - 2 means "some error occured".
@@ -1023,7 +1024,7 @@ int rad_check_multi(char *name, AUTH_REQ *authreq, VALUE_PAIR *reply,
 
 			/* Skip duplicates */
 			if (port >= 0 && u.nas_port == port &&
-			    u.nas_address == ipaddr)
+			    ntohl(u.nas_address) == ipaddr)
 				continue;
 
 			count++;
@@ -1057,7 +1058,7 @@ int rad_check_multi(char *name, AUTH_REQ *authreq, VALUE_PAIR *reply,
 
 			/* Skip duplicates */
 			if (port >= 0 && u.nas_port == port &&
-			    u.nas_address == ipaddr)
+			    ntohl(u.nas_address) == ipaddr)
 				continue;
 
 			if ((i = rad_check_ts(&u)) == 1) {
