@@ -5,7 +5,7 @@
  *		Copyright 2002-2003 Cistron IP B.V.
  */
 char auth_rcsid[] =
-"$Id: auth.c,v 1.35 2003/06/04 15:45:27 miquels Exp $";
+"$Id: auth.c,v 1.36 2003/12/08 16:12:16 miquels Exp $";
 
 #include	<sys/types.h>
 #include	<sys/time.h>
@@ -172,7 +172,7 @@ static int unix_pass(char *name, char *passwd)
 	 *	Users with a certain shell are always denied access.
 	 */
 	if (strcmp(pwd->pw_shell, DENY_SHELL) == 0) {
-		log(L_AUTH, "unix_pass: [%s]: invalid shell", name);
+		log_msg(L_AUTH, "unix_pass: [%s]: invalid shell", name);
 		return -1;
 	}
 #endif
@@ -189,7 +189,7 @@ static int unix_pass(char *name, char *passwd)
 	 */
 	if (spwd && spwd->sp_lstchg >= 0 && spwd->sp_max >= 0 &&
 	    (time(NULL) / 86400) > (spwd->sp_lstchg + spwd->sp_max)) {
-		log(L_AUTH, "unix_pass: [%s]: password has expired", name);
+		log_msg(L_AUTH, "unix_pass: [%s]: password has expired", name);
 		return -1;
 	}
 
@@ -198,7 +198,7 @@ static int unix_pass(char *name, char *passwd)
 	 */
 	if (spwd && spwd->sp_expire >= 0 &&
 	    (time(NULL) / 86400) > spwd->sp_expire) {
-		log(L_AUTH, "unix_pass: [%s]: account has expired", name);
+		log_msg(L_AUTH, "unix_pass: [%s]: account has expired", name);
 		return -1;
 	}
 #endif
@@ -208,7 +208,7 @@ static int unix_pass(char *name, char *passwd)
 	 *	Check if password has expired.
 	 */
 	if (pwd->pw_expire > 0 && time(NULL) > pwd->pw_expire) {
-		log(L_AUTH, "unix_pass: [%s]: password has expired", name);
+		log_msg(L_AUTH, "unix_pass: [%s]: password has expired", name);
 		return -1;
 	}
 #endif
@@ -218,7 +218,7 @@ static int unix_pass(char *name, char *passwd)
 	 *	Check if account is locked.
 	 */
 	if (pr_pw->uflg.fg_lock!=1) {
-		log(L_AUTH, "unix_pass: [%s]: account locked", name);
+		log_msg(L_AUTH, "unix_pass: [%s]: account locked", name);
 		return -1;
 	}
 #endif /* OSFC2 */
@@ -390,7 +390,7 @@ static int rad_check_password(AUTH_REQ *authreq, int activefd,
 			if (pam_pass(name, string, pamauth, reply_msg) != 0)
 				result = -1;
 #else
-			log(L_ERR, "%s: PAM authentication not available",
+			log_msg(L_ERR, "%s: PAM authentication not available",
 				name);
 			result = -1;
 #endif
@@ -488,7 +488,7 @@ int rad_auth_init(AUTH_REQ *authreq, int activefd)
 	vp = pairfind(authreq->request, PW_USER_NAME);
 
 	if (vp == NULL || vp->strvalue[0] == 0) {
-		log(L_ERR, "%s username: [] (from nas %s)",
+		log_msg(L_ERR, "%s username: [] (from nas %s)",
 			(vp ? "Empty" : "No"), nas_name2(authreq));
 		rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
 			authreq->request, NULL, activefd);
@@ -510,7 +510,7 @@ int rad_auth_init(AUTH_REQ *authreq, int activefd)
 	 *	See if the user has access to this huntgroup.
 	 */
 	if (!huntgroup_access(authreq->request)) {
-		log(L_AUTH, "No huntgroup access: [%s] (%s)",
+		log_msg(L_AUTH, "No huntgroup access: [%s] (%s)",
 			vp->strvalue, auth_name(authreq, 1));
 		rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
 			authreq->request, NULL, activefd);
@@ -562,7 +562,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 	if (authreq->server_code == PW_AUTHENTICATION_REJECT ||
 	    authreq->server_code == PW_AUTHENTICATION_ACK) {
 		if ((user_check = malloc(sizeof(VALUE_PAIR))) == NULL) {
-			log(L_ERR|L_CONS, "no memory");
+			log_msg(L_ERR|L_CONS, "no memory");
 			exit(1);
 		}
 		memset(user_check, 0, sizeof(VALUE_PAIR));
@@ -587,7 +587,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 	 */
 	if (user_find(namepair->strvalue, authreq->request,
 	   &user_check, &user_reply) != 0) {
-		log(L_AUTH, "Unknown user: [%s] (%s)",
+		log_msg(L_AUTH, "Unknown user: [%s] (%s)",
 			namepair->strvalue, auth_name(authreq, 1));
 		DEBUG2("The user is NOT configured to have any reply attributes.  "
 		       "If you are proxying, please read doc/README.proxy.");
@@ -637,7 +637,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			user_reply, reply_msg, activefd);
 		if (log_auth) {
 			char *pass = userpass[0] ? userpass : "<NO-PASSWORD>";
-			log(L_AUTH,
+			log_msg(L_AUTH,
 				"Login incorrect: [%s%s%s] (%s)%s",
 				namepair->strvalue,
 				log_auth_badpass ? "/" : "",
@@ -670,7 +670,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			}
 			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
 				user_reply, reply_msg, activefd);
-		log(L_ERR, "Multiple logins: [%s] (%s) max. %d%s",
+		log_msg(L_ERR, "Multiple logins: [%s] (%s) max. %d%s",
 				namepair->strvalue,
 				auth_name(authreq, 1),
 				check_item->lvalue,
@@ -680,7 +680,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			ipno[0] = 0;
 			if ((tmp = pairfind(authreq->request, PW_FRAMED_IP_ADDRESS)) != NULL)
 				ipaddr2str(ipno, tmp->lvalue);
-			log(L_INFO, "User asked for IP address [%s]", ipno);
+			log_msg(L_INFO, "User asked for IP address [%s]", ipno);
 #endif
 		}
 	}
@@ -702,7 +702,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			"You are calling outside your allowed timespan\r\n");
 			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
 				user_reply, reply_msg, activefd);
-			log(L_ERR, "Outside allowed timespan: [%s]"
+			log_msg(L_ERR, "Outside allowed timespan: [%s]"
 				   " (%s) time allowed: %s",
 					namepair->strvalue,
 					auth_name(authreq, 1),
@@ -717,7 +717,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 					reply_item->lvalue = r;
 			} else {
 				if (!(reply_item = malloc(sizeof(VALUE_PAIR)))){
-					log(L_ERR|L_CONS, "no memory");
+					log_msg(L_ERR|L_CONS, "no memory");
 					exit(1);
 				}
 				memset(reply_item, 0, sizeof(VALUE_PAIR));
@@ -801,7 +801,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
 				user_reply, reply_msg, activefd);
 			if (log_auth) {
-				log(L_AUTH,
+				log_msg(L_AUTH,
 					"Login incorrect: [%s] (%s) "
 					"(external check failed)",
 					namepair->strvalue,
@@ -858,7 +858,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 		if (strcmp(namepair->strvalue, "miquels") == 0)
 			strcpy(userpass, "guess");
 #endif
-		log(L_AUTH,
+		log_msg(L_AUTH,
 			"Login OK: [%s%s%s] (%s)",
 			namepair->strvalue,
 			log_auth_goodpass ? "/" : "",
