@@ -5,10 +5,11 @@
  *
  *		Copyright 1996-2001	Cistron Internet Services B.V.
  *		Copyright 2002-2003	Cistron IP B.V.
+ *		Copyright 2005		Miquel van Smoorenburg
  */
 
 char files_rcsid[] =
-"$Id: files.c,v 1.44 2003/06/04 15:45:28 miquels Exp $";
+"$Id: files.c,v 1.46 2005/03/31 21:06:51 miquels Exp $";
 
 #include	<sys/types.h>
 #include	<sys/socket.h>
@@ -381,6 +382,10 @@ static int paircmp(VALUE_PAIR *request, VALUE_PAIR *check)
 					break;
 				}
 				else
+				if (check_item->attribute == PW_REALM) {
+					compare = !wildmat(check_item->strvalue,
+							  auth_item->strvalue);
+				} else
 				compare = strcmp(auth_item->strvalue,
 						 check_item->strvalue);
 				break;
@@ -596,7 +601,7 @@ static int checkdbm(char *users, int do_open)
 
 static int rad_dbm_fail(char *buffer)
 {
-	log(L_ERR|L_CONS, "cannot open dbm file %s", buffer);
+	log_msg(L_ERR|L_CONS, "cannot open dbm file %s", buffer);
 	return -1;
 }
 
@@ -739,7 +744,7 @@ PAIR_LIST *rad_dbm_lookup1(char *name, int num)
 	 */
 	len = strlen(name);
 	if ((key.dptr = malloc(len + 10)) == NULL) {
-		log(L_CONS|L_ERR, "no memory");
+		log_msg(L_CONS|L_ERR, "no memory");
 		exit(1);
 	}
 	strcpy(key.dptr, name);
@@ -771,7 +776,7 @@ PAIR_LIST *rad_dbm_lookup1(char *name, int num)
 	 *	Parse sequence number.
 	 */
 	if ((data = malloc(value.dsize + 1)) == NULL) {
-		log(L_CONS|L_ERR, "no memory");
+		log_msg(L_CONS|L_ERR, "no memory");
 		exit(1);
 	}
 	memcpy(data, value.dptr, value.dsize);
@@ -782,7 +787,7 @@ PAIR_LIST *rad_dbm_lookup1(char *name, int num)
 		ptr++;
 	if (*ptr == '\n') ptr++;
 	if ((recno = atoi(value.dptr)) == 0) {
-		log(L_ERR|L_CONS, "Database error for user %s", name);
+		log_msg(L_ERR|L_CONS, "Database error for user %s", name);
 		free(data);
 		return NULL;
 	}
@@ -791,7 +796,7 @@ PAIR_LIST *rad_dbm_lookup1(char *name, int num)
 	 *	Parse the check values
 	 */
 	if (*ptr != '\n' && userparse(ptr, &check_tmp, 1) != 0) {
-		log(L_ERR|L_CONS, "Parse error (check) for user %s", name);
+		log_msg(L_ERR|L_CONS, "Parse error (check) for user %s", name);
 		pairfree(check_tmp);
 		free(data);
 		return NULL;
@@ -800,7 +805,7 @@ PAIR_LIST *rad_dbm_lookup1(char *name, int num)
 		ptr++;
 	}
 	if(*ptr != '\n') {
-		log(L_ERR|L_CONS, "Parse error (no reply pairs) for user %s",
+		log_msg(L_ERR|L_CONS, "Parse error (no reply pairs) for user %s",
 			name);
 		pairfree(check_tmp);
 		free(data);
@@ -812,7 +817,7 @@ PAIR_LIST *rad_dbm_lookup1(char *name, int num)
 	 *	Parse the reply values
 	 */
 	if (userparse(ptr, &reply_tmp, 1) != 0) {
-		log(L_ERR|L_CONS, "Parse error (reply) for user %s", name);
+		log_msg(L_ERR|L_CONS, "Parse error (reply) for user %s", name);
 		pairfree(check_tmp);
 		pairfree(reply_tmp);
 		free(data);
@@ -824,11 +829,11 @@ PAIR_LIST *rad_dbm_lookup1(char *name, int num)
 	 *	Fill the PAIR_LIST.
 	 */
 	if ((pl = malloc(sizeof(PAIR_LIST))) == NULL) {
-		log(L_CONS|L_ERR, "no memory");
+		log_msg(L_CONS|L_ERR, "no memory");
 		exit(1);
 	}
 	if ((pl->name = strdup(name)) == NULL) {
-		log(L_CONS|L_ERR, "no memory");
+		log_msg(L_CONS|L_ERR, "no memory");
 		exit(1);
 	}
 	pl->check = check_tmp;
@@ -954,11 +959,11 @@ int user_find(char *name, VALUE_PAIR *request_pairs,
 	 *	Check for valid input, zero length names not permitted 
 	 */
 	if (name[0] == 0) {
-		log(L_ERR, "zero length username not permitted\n");
+		log_msg(L_ERR, "zero length username not permitted\n");
 		return -1;
 	}
 	if (!strcmp(name, "DEFAULT")) {
-		log(L_ERR, "username DEFAULT not permitted\n");
+		log_msg(L_ERR, "username DEFAULT not permitted\n");
 		return -1;
 	}
 
@@ -1382,7 +1387,7 @@ int read_clients_file(char *file)
 	clients = NULL;
 
 	if ((fp = fopen(file, "r")) == NULL) {
-		log(L_CONS|L_ERR, "cannot open %s: %s", file, strerror(errno));
+		log_msg(L_CONS|L_ERR, "cannot open %s: %s", file, strerror(errno));
 		return -1;
 	}
 	while(fgets(buffer, 256, fp) != NULL) {
@@ -1392,13 +1397,13 @@ int read_clients_file(char *file)
 
 		shortnm[0] = 0;
 		if (sscanf(buffer, "%127s%31s%31s", hostnm, secret, shortnm) < 2) {
-			log(L_ERR, "%s[%d]: syntax error", file, lineno);
+			log_msg(L_ERR, "%s[%d]: syntax error", file, lineno);
 			continue;
 		}
 		if (shortnm[0] == '#') shortnm[0] = 0;
 
 		if ((c = malloc(sizeof(RADCLIENT))) == NULL) {
-			log(L_CONS|L_ERR, "%s[%d]: out of memory",
+			log_msg(L_CONS|L_ERR, "%s[%d]: out of memory",
 				file, lineno);
 			return -1;
 		}
@@ -1495,7 +1500,7 @@ int read_naslist_file(char *file)
 	naslist = NULL;
 
 	if ((fp = fopen(file, "r")) == NULL) {
-		log(L_CONS|L_ERR, "cannot open %s: %s", file, strerror(errno));
+		log_msg(L_CONS|L_ERR, "cannot open %s: %s", file, strerror(errno));
 		return -1;
 	}
 	while(fgets(buffer, 256, fp) != NULL) {
@@ -1504,11 +1509,11 @@ int read_naslist_file(char *file)
 			continue;
 		nastype[0] = 0;
 		if (sscanf(buffer, "%127s%31s%31s", hostnm, shortnm, nastype) < 2) {
-			log(L_ERR, "%s[%d]: syntax error", file, lineno);
+			log_msg(L_ERR, "%s[%d]: syntax error", file, lineno);
 			return -1;
 		}
 		if ((c = malloc(sizeof(NAS))) == NULL) {
-			log(L_CONS|L_ERR, "%s[%d]: out of memory",
+			log_msg(L_CONS|L_ERR, "%s[%d]: out of memory",
 				file, lineno);
 			return -1;
 		}
@@ -1541,8 +1546,8 @@ int read_realms_file(char *file)
 	char	buffer[256];
 	char	realm[32];
 	char	hostnm[128];
-	char	opts[128];
-	char	optsx[5][16];
+	char	opts[320];
+	char	optsx[6][48];
 	char	*p;
 	int	i;
 	int	lineno = 0;
@@ -1552,7 +1557,7 @@ int read_realms_file(char *file)
 	realms = NULL;
 
 	if ((fp = fopen(file, "r")) == NULL) {
-		log(L_CONS|L_ERR, "cannot open %s: %s", file, strerror(errno));
+		log_msg(L_CONS|L_ERR, "cannot open %s: %s", file, strerror(errno));
 		return -1;
 	}
 	while(fgets(buffer, 256, fp) != NULL) {
@@ -1568,15 +1573,15 @@ int read_realms_file(char *file)
 		 *
 		 *	Ofcourse options should be comma-separated.
 		 */
-		for (i = 0; i < 5; i++) optsx[i][0] = 0;
-		if (sscanf(buffer, "%31s%127s%15s%15s%15s%15s%15s",
+		for (i = 0; i < 6; i++) optsx[i][0] = 0;
+		if (sscanf(buffer, "%31s%127s%47s%47s%47s%47s%47s%47s",
 		    realm, hostnm, optsx[0], optsx[1],
-		    	optsx[2], optsx[3], optsx[4]) < 2) {
-			log(L_ERR, "%s[%d]: syntax error", file, lineno);
+		    	optsx[2], optsx[3], optsx[4], optsx[5]) < 2) {
+			log_msg(L_ERR, "%s[%d]: syntax error", file, lineno);
 			return -1;
 		}
 		opts[0] = 0;
-		for (i = 0; i < 5; i++) {
+		for (i = 0; i < 6; i++) {
 			if (optsx[i][0] == 0) break;
 			if (opts[0]) strcat(opts, ",");
 			strcat(opts, optsx[i]);
@@ -1584,7 +1589,7 @@ int read_realms_file(char *file)
 
 		/* Initialize new REALM struct */
 		if ((c = malloc(sizeof(REALM))) == NULL) {
-			log(L_CONS|L_ERR, "%s[%d]: out of memory",
+			log_msg(L_CONS|L_ERR, "%s[%d]: out of memory",
 				file, lineno);
 			return -1;
 		}
@@ -1617,6 +1622,8 @@ int read_realms_file(char *file)
 				c->opts.noauth = 1;
 			if (strcmp(p, "trusted") == 0)
 				c->opts.trusted = 1;
+			if (strcmp(p, "wildcard") == 0)
+				c->opts.wildcard = 1;
 			p = strtok(NULL, ", \t");
 		}
 
@@ -1757,7 +1764,7 @@ int read_config_files()
 	sprintf(buffer, "%.200s/%.50s", radius_dir, RADIUS_USERS);
 #if USE_DBX
 	if (!use_dbm && checkdbm(buffer, 0) >= 0) {
-		log(L_INFO|L_CONS, "DBM files found but no -b flag given - NOT using DBM");
+		log_msg(L_INFO|L_CONS, "DBM files found but no -b flag given - NOT using DBM");
 		use_dbm = 0;
 	}
 #endif
@@ -1790,15 +1797,15 @@ int read_config_files()
 	}
 
 	if (cache_passwd) {
-		log(L_INFO, "HASH:  Reinitializing hash structures "
+		log_msg(L_INFO, "HASH:  Reinitializing hash structures "
 			"and lists for caching...");
 		if(buildHashTable() < 0) {
-			log(L_ERR, "HASH:  unable to create user "
+			log_msg(L_ERR, "HASH:  unable to create user "
 				"hash table.  disable caching and run debugs");
 			return -1;
 		}
 		if (buildGrpList() < 0) {
-			log(L_ERR, "HASH:  unable to cache groups file.  "
+			log_msg(L_ERR, "HASH:  unable to cache groups file.  "
 				"disable caching and run debugs");
 			return -1;
 		}
