@@ -5,7 +5,7 @@
  */
 
 char log_rcsid[] =
-"$Id: log.c,v 1.12 2001/07/24 18:54:33 miquels Exp $";
+"$Id: log.c,v 1.13 2003/12/08 16:12:19 miquels Exp $";
 
 #include	<stdio.h>
 #include	<stdlib.h>
@@ -157,7 +157,7 @@ int log_debug(char *msg, ...)
 	return r;
 }
 
-int log(int lvl, char *msg, ...)
+int log_msg(int lvl, char *msg, ...)
 {
 	va_list ap;
 	int r;
