@@ -7,7 +7,7 @@
  */
 
 char pair_rcsid[] =
-"$Id: pair.c,v 1.19 2003/06/04 15:45:28 miquels Exp $";
+"$Id: pair.c,v 1.20 2003/12/08 16:12:19 miquels Exp $";
 
 #include	<sys/types.h>
 #include	<sys/time.h>
@@ -498,7 +498,7 @@ int userparse(char *buffer, VALUE_PAIR **first_pair, int resolve)
 
 			/* Now look up the (possibly stripped) attribute name */
 			if ((attr = dict_attrfind(attrstr)) == NULL) {
-				log(L_ERR|L_CONS, "Unknown attribute \"%s\"",
+				log_msg(L_ERR|L_CONS, "Unknown attribute \"%s\"",
 					attrstr);
 				return(-1);
 			}
@@ -553,7 +553,7 @@ int userparse(char *buffer, VALUE_PAIR **first_pair, int resolve)
 				operator = PW_OPERATOR_SUB;
 			}
 			else {
-				log(L_ERR|L_CONS,
+				log_msg(L_ERR|L_CONS,
 					"Unexpected character `%c' (0x%02x)",
 					*buffer, *buffer);
 				return -1;
@@ -592,7 +592,7 @@ int userparse(char *buffer, VALUE_PAIR **first_pair, int resolve)
 			fieldcpy(valstr, sizeof(valstr), &buffer);
 			if((pair = (VALUE_PAIR *)malloc(sizeof(VALUE_PAIR))) ==
 						(VALUE_PAIR *)NULL) {
-				log(L_CONS|L_ERR, "no memory");
+				log_msg(L_CONS|L_ERR, "no memory");
 				exit(1);
 			}
 			memset(pair, 0, sizeof(VALUE_PAIR));
@@ -622,7 +622,7 @@ int userparse(char *buffer, VALUE_PAIR **first_pair, int resolve)
 				base = 10 + 6 * (strncmp(valstr, "0x", 2) == 0);
 				if (!isdigit(*s)) {
 					free(pair);
-					log(L_ERR|L_CONS,
+					log_msg(L_ERR|L_CONS,
 					"Only numerical value allowed "
 					"for attribute %s", attr->name);
 					return -1;
@@ -639,7 +639,7 @@ int userparse(char *buffer, VALUE_PAIR **first_pair, int resolve)
 #else
 				if (base != 16) {
 					free(pair);
-					log(L_ERR|L_CONS,
+					log_msg(L_ERR|L_CONS,
 					"Only hex value allowed "
 					"for attribute %s", attr->name);
 					return -1;
@@ -669,7 +669,7 @@ int userparse(char *buffer, VALUE_PAIR **first_pair, int resolve)
 				}
 				else if ((dval = dict_valfind(valstr, attr->name)) == NULL) {
 					free(pair);
-					log(L_ERR|L_CONS,
+					log_msg(L_ERR|L_CONS,
 					"Unknown value \"%s\" for attribute %s",
 						valstr, attr->name);
 					return(-1);
@@ -724,7 +724,7 @@ int userparse(char *buffer, VALUE_PAIR **first_pair, int resolve)
 
 			default:
 				free(pair);
-				log(L_ERR|L_CONS, "Unknown attribute type %d",
+				log_msg(L_ERR|L_CONS, "Unknown attribute type %d",
 					pair->type);
 				return(-1);
 			}
@@ -742,7 +742,7 @@ int userparse(char *buffer, VALUE_PAIR **first_pair, int resolve)
 	 *	Double-check that we've parsed a complete Attribute=value
 	 */
 	if (mode != PARSE_MODE_NAME) {
-		log(L_ERR|L_CONS, "Got end of line while still parsing last attribute");
+		log_msg(L_ERR|L_CONS, "Got end of line while still parsing last attribute");
 		return(-1);
 	}
 
