@@ -6,7 +6,7 @@
  */
 
 char proxy_rcsid[] =
-"$Id: proxy.c,v 1.26 2003/06/04 15:45:28 miquels Exp $";
+"$Id: proxy.c,v 1.27 2003/12/08 16:12:20 miquels Exp $";
 
 #include	<sys/types.h>
 #include	<sys/socket.h>
@@ -42,6 +42,15 @@ static int allowed [] = {
 	PW_SESSION_TIMEOUT,
 	PW_IDLE_TIMEOUT,
 	PW_PORT_LIMIT,
+	PW_TUNNEL_TYPE,
+	PW_TUNNEL_MEDIUM_TYPE,
+	PW_TUNNEL_SERVER_ENDPOINT,
+	PW_TUNNEL_PASSWORD,
+	PW_TUNNEL_PRIVATE_GROUP_ID,
+	PW_TUNNEL_ASSIGNMENT_ID,
+	PW_TUNNEL_PREFERENCE,
+	PW_TUNNEL_CLIENT_AUTH_ID,
+	PW_TUNNEL_SERVER_AUTH_ID,
 	0,
 };
 
@@ -82,7 +91,7 @@ static VALUE_PAIR *proxy_addinfo(AUTH_REQ *authreq)
 	VALUE_PAIR		*proxy_pair, *vp;
 
 	if  (!(proxy_pair = (VALUE_PAIR *)malloc(sizeof(VALUE_PAIR)))) {
-		log(L_ERR|L_CONS, "no memory");
+		log_msg(L_ERR|L_CONS, "no memory");
 		exit(1);
 	}
 	memset(proxy_pair, 0, sizeof(VALUE_PAIR));
@@ -144,7 +153,7 @@ int proxy_addrequest(AUTH_REQ *authreq, int *proxy_id)
 	 *	Copy the static data into malloc()ed memory.
 	 */
 	if ((m = malloc(authreq->data_len)) == NULL) {
-		log(L_ERR|L_CONS, "no memory");
+		log_msg(L_ERR|L_CONS, "no memory");
 		exit(1);
 	}
 	memcpy(m, authreq->data, authreq->data_len);
@@ -293,7 +302,7 @@ int proxy_send(AUTH_REQ *authreq, int activefd)
 	 *	Remember that we sent the request to a Realm.
 	 */
 	if ((vp = (VALUE_PAIR *)malloc(sizeof(VALUE_PAIR))) == NULL) {
-		log(L_ERR|L_CONS, "no memory");
+		log_msg(L_ERR|L_CONS, "no memory");
 		exit(1);
 	}
 	memset(vp, 0, sizeof(VALUE_PAIR));
@@ -327,7 +336,7 @@ int proxy_send(AUTH_REQ *authreq, int activefd)
 	}
 
 	if ((client = client_find(realm->ipaddr)) == NULL) {
-		log(L_PROXY, "cannot find secret for server %s in clients file",
+		log_msg(L_PROXY, "cannot find secret for server %s in clients file",
 			realm->server);
 		return 0;
 	}
@@ -411,7 +420,7 @@ int proxy_send(AUTH_REQ *authreq, int activefd)
 	if (pairfind(authreq->request, PW_CHAP_PASSWORD) &&
 	    pairfind(authreq->request, PW_CHAP_CHALLENGE) == NULL) {
 		if (!(vp = (VALUE_PAIR *)malloc(sizeof(VALUE_PAIR)))) {
-			log(L_ERR|L_CONS, "no memory");
+			log_msg(L_ERR|L_CONS, "no memory");
 			exit(1);
 		}
 		memset(vp, 0, sizeof(VALUE_PAIR));
@@ -530,7 +539,7 @@ int proxy_receive(AUTH_REQ *authreq, int activefd)
 		    isxdigit(s[2]) && isxdigit(s[3])) {
 			pp = strtol(last->strvalue, NULL, 16);
 		} else {
-			log(L_PROXY, "server %s mangled Proxy-State attribute",
+			log_msg(L_PROXY, "server %s mangled Proxy-State attribute",
 			client_name(authreq->ipaddr));
 		}
 	}
@@ -554,7 +563,7 @@ int proxy_receive(AUTH_REQ *authreq, int activefd)
 	}
 
 	if (oldreq == NULL) {
-		log(L_PROXY, "Unrecognized proxy reply from server %s - ID %d",
+		log_msg(L_PROXY, "Unrecognized proxy reply from server %s - ID %d",
 			client_name(authreq->ipaddr), authreq->id);
 		return -1;
 	}
