@@ -7,7 +7,7 @@
  */
 
 char radius_rcsid[] =
-"$Id: radius.c,v 1.24 2003/06/04 15:45:28 miquels Exp $";
+"$Id: radius.c,v 1.25 2003/12/08 16:12:20 miquels Exp $";
 
 #include	<sys/types.h>
 #include	<sys/socket.h>
@@ -383,7 +383,7 @@ int rad_send_reply(int code, AUTH_REQ *authreq, VALUE_PAIR *oreply,
 			sprintf(tmp, "id %d", authreq->id);
 			n = tmp;
 		}
-		log(L_ERR, "error sending radius packet for %s: %s", n,
+		log_msg(L_ERR, "error sending radius packet for %s: %s", n,
 			strerror(errno));
 	}
 
@@ -449,7 +449,7 @@ int calc_acctdigest(u_char *digest, AUTH_REQ *authreq)
 	memset(recvbuf + 4, 0, AUTH_VECTOR_LEN);
 
 	if ((tmpbuf = malloc(len + secretlen)) == NULL) {
-		log(L_ERR|L_CONS, "no memory");
+		log_msg(L_ERR|L_CONS, "no memory");
 		exit(1);
 	}
 	memcpy(tmpbuf, recvbuf, len);
@@ -474,7 +474,7 @@ static VALUE_PAIR *decode_attr(AUTH_REQ *authreq, u_char *ptr,
 	UINT4		lvalue;
 
 	if ((pair = (VALUE_PAIR *)malloc(sizeof(VALUE_PAIR))) == NULL) {
-		log(L_ERR|L_CONS, "no memory");
+		log_msg(L_ERR|L_CONS, "no memory");
 		exit(1);
 	}
 	memset(pair, 0, sizeof(VALUE_PAIR));
@@ -712,7 +712,7 @@ AUTH_REQ	*radrecv(UINT4 host, u_short udp_port,
 
 	if ((authreq = (AUTH_REQ *)malloc(sizeof(AUTH_REQ))) ==
 						(AUTH_REQ *)NULL) {
-		log(L_ERR|L_CONS, "no memory");
+		log_msg(L_ERR|L_CONS, "no memory");
 		exit(1);
 	}
 	memset(authreq, 0, sizeof(AUTH_REQ));
@@ -754,7 +754,7 @@ AUTH_REQ	*radrecv(UINT4 host, u_short udp_port,
 	 *	user's request.
 	 */
 	if ((pair = malloc(sizeof(VALUE_PAIR))) == NULL) {
-		log(L_CONS|L_ERR, "no memory");
+		log_msg(L_CONS|L_ERR, "no memory");
 		exit(1);
 	}
 	memset(pair, 0, sizeof(VALUE_PAIR));
