@@ -3,11 +3,13 @@
  *
  *		Copyright 1996-2001	Cistron Internet Services B.V.
  *		Copyright 2002-2003	Cistron IP B.V.
+ *		Copyright 2004		Cistron Broadband B.V.
+ *		Copyright 2005		Miquel van Smoorenburg
  */
 
 /* don't look here for the version, run radiusd -v or look in version.c */
 char radiusd_rcsid[] =
-"$Id: radiusd.c,v 1.29 2003/07/02 09:39:03 miquels Exp $";
+"$Id: radiusd.c,v 1.31 2005/03/31 21:06:51 miquels Exp $";
 
 #include	<sys/types.h>
 #include	<sys/socket.h>
@@ -102,9 +104,9 @@ static void reread_config(int reload)
 	int pid = getpid();
 
 	if (!reload) {
-		log(L_INFO, "Starting - reading configuration files ...");
+		log_msg(L_INFO, "Starting - reading configuration files ...");
 	} else if (pid == radius_pid) {
-		log(L_INFO, "Reloading configuration files.");
+		log_msg(L_INFO, "Reloading configuration files.");
 	}
 
 	/* Initialize the dictionary */
@@ -121,7 +123,7 @@ static void reread_config(int reload)
 
 	if (res != 0) {
 		if (pid == radius_pid) {
-			log(L_ERR|L_CONS,
+			log_msg(L_ERR|L_CONS,
 				"Errors reading config file - EXITING");
 			if (acct_pid) {
 				signal(SIGCHLD, SIG_DFL);
@@ -419,7 +421,7 @@ int main(int argc, char **argv)
 	if (debug_flag == 0 && dontfork == 0) {
 		pid = fork();
 		if(pid < 0) {
-			log(L_ERR|L_CONS, "Couldn't fork");
+			log_msg(L_ERR|L_CONS, "Couldn't fork");
 			exit(1);
 		}
 		if(pid > 0) {
@@ -470,20 +472,20 @@ int main(int argc, char **argv)
 	if (spawn_flag) {
 		acct_pid = fork();
 		if(acct_pid < 0) {
-			log(L_ERR|L_CONS, "Couldn't fork");
+			log_msg(L_ERR|L_CONS, "Couldn't fork");
 			exit(1);
 		}
 		if(acct_pid > 0) {
 			close(acctfd);
 			acctfd = -1;
-			log(L_INFO, "Ready to process requests.");
+			log_msg(L_INFO, "Ready to process requests.");
 		}
 		else {
 			close(sockfd);
 			sockfd = -1;
 		}
 	} else
-		log(L_INFO, "Ready to process requests.");
+		log_msg(L_INFO, "Ready to process requests.");
 
 
 	/*
@@ -610,8 +612,9 @@ int radrespond(AUTH_REQ *authreq, int activefd)
 	 *      See if we know this client.
 	 */
         if ((cl = client_find(authreq->ipaddr)) == NULL) {
-                log(L_ERR, "packet from unknown client/host: %s",
+                log_msg(L_ERR, "packet from unknown client/host: %s",
                         client_name(authreq->ipaddr));
+		authfree(authreq);
                 return -1;
         }
 	strNcpy(authreq->secret, cl->secret, sizeof(authreq->secret));
@@ -677,7 +680,7 @@ int radrespond(AUTH_REQ *authreq, int activefd)
 		/*
 		 *	We don't support this anymore.
 		 */
-		log(L_ERR, "Unsupported change password request packet "
+		log_msg(L_ERR, "Unsupported change password request packet "
 			   "from nas [%s]", client_name(authreq->ipaddr));
 		break;
 
@@ -686,7 +689,7 @@ int radrespond(AUTH_REQ *authreq, int activefd)
 		break;
 
 	default:
-		log(L_ERR, "Unknown packet type [%d] from nas [%s]",
+		log_msg(L_ERR, "Unknown packet type [%d] from nas [%s]",
 			authreq->code, client_name(authreq->ipaddr));
 		break;
 	}
@@ -760,7 +763,7 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
 			 *	3 seconds ago. Just drop it.
 			 */
 			vp = pairfind(authreq->request, PW_USER_NAME);
-			log(L_ERR,
+			log_msg(L_ERR,
 			"Duplicate authentication packet: [%s] (%s/ID:%d)",
 				vp ? vp->strvalue : "",
 				auth_name(authreq, 0), authreq->id);
@@ -777,7 +780,7 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
 				 *	kill it
 				 */
 				child_pid = curreq->child_pid;
-				log(L_ERR,
+				log_msg(L_ERR,
 					"Killing unresponsive child pid %d",
 								child_pid);
 				curreq->child_pid = -1;
@@ -793,7 +796,7 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
 	 *	This is a new request
 	 */
 	if (request_count > MAX_REQUESTS) {
-		log(L_ERR,
+		log_msg(L_ERR,
 		"Dropping packet (too many): from host %s:%d - ID: %d",
 			client_name(authreq->ipaddr), authreq->udp_port,
 			authreq->id);
@@ -821,7 +824,7 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
 	 *	fork our child
 	 */
 	if ((child_pid = fork()) < 0) {
-		log(L_ERR, "Fork failed for request from nas %s - ID: %d",
+		log_msg(L_ERR, "Fork failed for request from nas %s - ID: %d",
 				nas_name2(authreq), authreq->id);
 	}
 	if (child_pid == 0) {
@@ -955,16 +958,16 @@ static void sig_fatal(int sig)
 
 	switch(sig) {
 		case 100:
-			log(L_ERR, "%saccounting process died - exit.", me);
+			log_msg(L_ERR, "%saccounting process died - exit.", me);
 			break;
 		case 101:
-			log(L_ERR, "%sfailed in select() - exit.", me);
+			log_msg(L_ERR, "%sfailed in select() - exit.", me);
 			break;
 		case SIGTERM:
-			log(L_INFO, "%sexit.", me);
+			log_msg(L_INFO, "%sexit.", me);
 			break;
 		default:
-			log(L_ERR, "%sexit on signal (%d)", me, sig);
+			log_msg(L_ERR, "%sexit on signal (%d)", me, sig);
 			break;
 	}
 
