@@ -3,13 +3,25 @@
  *		compatibility stuff.
  *
  *		Copyright 1997-2000	Cistron Internet Services B.V.
+ *		Copyright 2002-2003	Cistron IP B.V.
  *
- * Version:	$Id: sysdep.h,v 1.9 2000/12/01 16:13:24 miquels Exp $
+ * Version:	$Id: sysdep.h,v 1.12 2003/06/04 15:45:28 miquels Exp $
  */
 
 #ifndef SYSDEP_H_INCLUDED
 #define SYSDEP_H_INCLUDED
 
+#ifdef __GNUC__
+#  define USE_LONGLONG 1
+#  if defined(__FreeBSD__) || defined(__NetBSD__) || defined(bsdi)
+#    define PERCENT_LONGLONG "%qu"
+#  elif defined(__linux__)
+#    define PERCENT_LONGLONG "%Lu"
+#  else
+#    define PERCENT_LONGLONG "%llu"
+#  endif
+#endif
+
 #if defined(__FreeBSD__) || defined(__NetBSD__) || defined(bsdi) || defined(M_UNIX)
 #  ifndef NOSHADOW
 #    define NOSHADOW
@@ -22,6 +34,10 @@ typedef unsigned int	UINT4;
 typedef unsigned long	UINT4;
 #endif
 
+#if defined(USE_LONGLONG)
+typedef unsigned long long UINT8;
+#endif
+
 #ifdef BSD
 #include        <strings.h>
 #else
