@@ -9,7 +9,7 @@
  */
 
 char util_rcsid[] =
-"$Id: util.c,v 1.10 2002/01/23 12:42:07 miquels Exp $";
+"$Id: util.c,v 1.12 2002/07/02 15:28:01 miquels Exp $";
 
 #include	<sys/types.h>
 #include	<sys/socket.h>
@@ -239,3 +239,73 @@ char *strNcpy(char *dest, char *src, int n)
 	return dest;
 }
 
+
+#ifdef __GLIBC__
+
+/*
+ *	Glibc has a shell wildcard pattern matcher built-in.
+ */
+#include <fnmatch.h>
+int wildmat(char *pat, char *str)
+{
+	return (fnmatch(pat, str, 0) == 0);
+}
+
+#else
+
+/*
+ *	Wildcard pattern matcher - uses shell wildcards (?*[])
+ *	Standalone implementation by miquels.
+ */
+int wildmat(char *pat, char *str)
+{
+	char	*p;
+	int	i;
+
+	/*printf("wildmat pat=\"%s\" str=\"%s\"\n", pat, str);*/
+
+	while (*pat) {
+
+		if (*pat == '*') {
+			/* Star */
+			if (pat[1] == 0) return 1;
+			for (p = str; *p; p++)
+				if (wildmat(pat+1, p))
+					return 1;
+			return 0;
+		}
+
+		if (*pat == '?') {
+			/* ? matches any char */
+		} else if (*pat == '[') {
+			/* [...] */
+			i = 0;
+			while (*pat && *pat != ']') {
+				if (*pat != '\\' && pat[1] == '-' &&
+				    pat[2] && pat[2] != ']') {
+					/* Range */
+					if (*str >= *pat && *str <= pat[2])
+						i = 1;
+					pat += 3;
+				} else {
+					if (*pat == '\\' && pat[1])
+						pat++;
+					if (*pat++ == *str)
+						i = 1;
+				}
+			}
+			if (i == 0 || *pat == 0) return 0;
+		} else {
+			/* Plain char */
+			if (*pat == '\\' && pat[1]) pat++;
+			if (*pat != *str)
+				return 0;
+		}
+		pat++;
+		if (*str) str++;		
+	}
+	return (*str == 0);
+}
+
+#endif
+
